embassy-stm32

Crates

git

Versions

stm32h757ii-cm7

Flavors

CanHeader

Trait CanHeader 

pub trait CanHeader: Sized {
    // Required methods
    fn from_header(
        header: Header,
        data: &[u8],
    ) -> Result<Self, FrameCreateError>;
    fn header(&self) -> &Header;
}
Trait for FDCAN frame types, providing ability to construct from a Header and to retrieve the Header from a frame

Required Methods

fn from_header(header: Header, data: &[u8]) -> Result<Self, FrameCreateError>

Construct frame from header and payload

fn header(&self) -> &Header

Get this frame’s header struct

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors